@@ -16,6 +16,7 @@ package stack
 
 import (
 	"encoding/json"
+	"errors"
 	"fmt"
 	"io"
 	"io/ioutil"
@@ -23,7 +24,7 @@ import (
 	"strings"
 
 	"github.com/blang/semver"
-	"github.com/pkg/errors"
+
 	"github.com/pulumi/pulumi/pkg/v3/resource/deploy"
 	"github.com/pulumi/pulumi/pkg/v3/secrets"
 	"github.com/pulumi/pulumi/sdk/v3/go/common/apitype"
@@ -131,7 +132,7 @@ func SerializeDeployment(snap *deploy.Snapshot, sm secrets.Manager, showSecrets
 	if sm != nil {
 		e, err := sm.Encrypter()
 		if err != nil {
-			return nil, errors.Wrap(err, "getting encrypter for deployment")
+			return nil, fmt.Errorf("getting encrypter for deployment: %w", err)
 		}
 		enc = e
 	} else {
@@ -143,7 +144,7 @@ func SerializeDeployment(snap *deploy.Snapshot, sm secrets.Manager, showSecrets
 	for _, res := range snap.Resources {
 		sres, err := SerializeResource(res, enc, showSecrets)
 		if err != nil {
-			return nil, errors.Wrap(err, "serializing resources")
+			return nil, fmt.Errorf("serializing resources: %w", err)
 		}
 		resources = append(resources, sres)
 	}
@@ -351,7 +352,7 @@ func SerializeResource(res *resource.State, enc config.Encrypter, showSecrets bo
 func SerializeOperation(op resource.Operation, enc config.Encrypter, showSecrets bool) (apitype.OperationV2, error) {
 	res, err := SerializeResource(op.Resource, enc, showSecrets)
 	if err != nil {
-		return apitype.OperationV2{}, errors.Wrap(err, "serializing resource")
+		return apitype.OperationV2{}, fmt.Errorf("serializing resource: %w", err)
 	}
 	return apitype.OperationV2{
 		Resource: res,
@@ -438,7 +439,7 @@ func SerializePropertyValue(prop resource.PropertyValue, enc config.Encrypter,
 		}
 		bytes, err := json.Marshal(value)
 		if err != nil {
-			return nil, errors.Wrap(err, "encoding serialized property value")
+			return nil, fmt.Errorf("encoding serialized property value: %w", err)
 		}
 		plaintext := string(bytes)
 
@@ -451,7 +452,7 @@ func SerializePropertyValue(prop resource.PropertyValue, enc config.Encrypter,
 			ciphertext, err = enc.EncryptValue(plaintext)
 		}
 		if err != nil {
-			return nil, errors.Wrap(err, "failed to encrypt secret value")
+			return nil, fmt.Errorf("failed to encrypt secret value: %w", err)
 		}
 		contract.AssertNoErrorf(err, "marshalling underlying secret value to JSON")
 
@@ -485,15 +486,15 @@ func DeserializeResource(res apitype.ResourceV3, dec config.Decrypter, enc confi
 	}
 
 	if res.URN == "" {
-		return nil, errors.Errorf("resource missing required 'urn' field")
+		return nil, fmt.Errorf("resource missing required 'urn' field")
 	}
 
 	if res.Type == "" {
-		return nil, errors.Errorf("resource '%s' missing required 'type' field", res.URN)
+		return nil, fmt.Errorf("resource '%s' missing required 'type' field", res.URN)
 	}
 
 	if !res.Custom && res.ID != "" {
-		return nil, errors.Errorf("resource '%s' has 'custom' false but non-empty ID", res.URN)
+		return nil, fmt.Errorf("resource '%s' has 'custom' false but non-empty ID", res.URN)
 	}
 
 	return resource.NewState(
@@ -585,14 +586,14 @@ func DeserializePropertyValue(v interface{}, dec config.Decrypter,
 					if plainOk {
 						encryptedText, err := enc.EncryptValue(plaintext)
 						if err != nil {
-							return resource.PropertyValue{}, errors.Wrap(err, "encrypting secret value")
+							return resource.PropertyValue{}, fmt.Errorf("encrypting secret value: %w", err)
 						}
 						ciphertext = encryptedText
 
 					} else {
 						unencryptedText, err := dec.DecryptValue(ciphertext)
 						if err != nil {
-							return resource.PropertyValue{}, errors.Wrap(err, "decrypting secret value")
+							return resource.PropertyValue{}, fmt.Errorf("decrypting secret value: %w", err)
 						}
 						plaintext = unencryptedText
 					}
@@ -667,7 +668,7 @@ func DeserializePropertyValue(v interface{}, dec config.Decrypter,
 					}
 					return resource.MakeComponentResourceReference(urn, packageVersion), nil
 				default:
-					return resource.PropertyValue{}, errors.Errorf("unrecognized signature '%v' in property map", sig)
+					return resource.PropertyValue{}, fmt.Errorf("unrecognized signature '%v' in property map", sig)
 				}
 			}
 
