@@ -87,6 +87,41 @@ def inherited_child_alias(
 
     return create_urn(alias_name, child_type, parent_alias)
 
+# Extract the type and name parts of a URN
+def urn_type_and_name(urn: str) -> Tuple[str, str]:
+    parts = urn.split("::")
+    type_parts = parts[2].split("$")
+    return (parts[3], type_parts[-1])
+
+def all_aliases(
+    child_aliases: Optional[Sequence['Input[Union[str, Alias]]']],
+    child_name: str,
+    child_type: str,
+    parent: Optional['Resource']) -> 'List[Input[str]]':
+    """
+    Make a copy of the aliases array, and add to it any implicit aliases inherited from its parent.
+    If there are N child aliases, and M parent aliases, there will be (M+1)*(N+1)-1 total aliases,
+    or, as calculated in the logic below, N+(M*(1+N)).
+    """
+    aliases: 'List[Input[str]]' = []
+
+    for child_alias in child_aliases or []:
+        aliases.append(collapse_alias_to_urn(child_alias, child_name, child_type, parent))
+
+    if parent is not None:
+        parent_name = parent._name
+        for parent_alias in parent._aliases:
+            aliases.append(inherited_child_alias(child_name, parent._name, parent_alias, child_type))
+            for child_alias in child_aliases or []:
+                child_alias_urn = collapse_alias_to_urn(child_alias, child_name, child_type, parent)
+                def inherited_alias_for_child_urn(child_alias_urn: str, parent_alias=parent_alias) -> 'Output[str]':
+                    aliased_child_name, aliased_child_type = urn_type_and_name(child_alias_urn)
+                    return inherited_child_alias(aliased_child_name, parent_name, parent_alias, aliased_child_type)
+                inherited_alias: Output[str] = child_alias_urn.apply(inherited_alias_for_child_urn)
+                aliases.append(inherited_alias)
+
+    return aliases
+
 
 ROOT_STACK_RESOURCE = None
 """
@@ -740,17 +775,6 @@ class Resource:
             if opts.protect is None:
                 opts.protect = opts.parent._protect
 
-            # Make a copy of the aliases array, and add to it any implicit aliases inherited from
-            # its parent
-            if opts.aliases is None:
-                opts.aliases = []
-
-            opts.aliases = list(opts.aliases)
-            for parent_alias in opts.parent._aliases:
-                child_alias = inherited_child_alias(
-                    name, opts.parent._name, parent_alias, t)
-                opts.aliases.append(cast('Output[Union[str, Alias]]', child_alias))
-
             # Infer providers and provider maps from parent, if one was provided.
             self._providers = opts.parent._providers
 
@@ -775,15 +799,7 @@ class Resource:
         self._protect = bool(opts.protect)
         self._provider = opts.provider if custom else None
         self._version = opts.version
-
-        # Collapse any `Alias`es down to URNs. We have to wait until this point to do so because we
-        # do not know the default `name` and `type` to apply until we are inside the resource
-        # constructor.
-        self._aliases: 'List[Input[str]]' = []
-        if opts.aliases is not None:
-            for alias in opts.aliases:
-                self._aliases.append(collapse_alias_to_urn(
-                    alias, name, t, opts.parent))
+        self._aliases = all_aliases(opts.aliases, name, t, opts.parent)
 
         if opts.urn is not None:
             # This is a resource that already exists. Read its state from the engine.
@@ -921,8 +937,7 @@ class ComponentResource(Resource):
 
         :param dict output: A dictionary of outputs to associate with this resource.
         """
-        if outputs:
-            register_resource_outputs(self, outputs)
+        register_resource_outputs(self, outputs)
 
 
 class ProviderResource(CustomResource):
